# prosodia
`prosodia` is a library to parse arbitrary grammars and then apply a
deterministic transformation.

## TODOs
- Add a validity check to a language that checks that there are no unused rules
